@@ -1,6 +1,6 @@
 /*
 #   avcodecdecode.c: decodes wma file format for xlplayer
-#   Copyright (C) 2007-2013 Stephen Fairchild (s-fairchild@users.sf.net)
+#   Copyright (C) 2007-2017 Stephen Fairchild (s-fairchild@users.sf.net)
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -48,17 +48,237 @@
 #ifndef HAVE_AV_FRAME_UNREF
 #define av_frame_unref avcodec_get_frame_defaults
 #endif
+#ifndef HAVE_AV_PACKET_UNREF
+#define av_packet_unref av_free_packet
+#endif
 
 extern int dynamic_metadata_form[];
 
 static const struct timespec time_delay = { .tv_nsec = 10 };
 
+static void write_frame(struct xlplayer *xlplayer, AVFrame *frame)
+    {
+    struct avcodecdecode_vars *self = xlplayer->dec_data;
+    int frames;
+    int channels = self->c->channels;
+    SRC_DATA *src_data = &xlplayer->src_data;
+
+#if defined (HAVE_SWRESAMPLE) && defined(USE_SWRESAMPLE)
+    if (!self->swr)
+        {
+        int64_t layout;
+
+        if (!(self->swr = swr_alloc()))
+            {
+            fprintf(stderr, "avcodecdecode_play: call to swr_alloc failed\n");
+            xlplayer->playmode = PM_EJECTING;
+            return;
+            }
+
+        layout = frame->channel_layout;
+        if (!layout)
+            layout = self->c->channel_layout;
+        if (!layout)
+            {
+            if (!channels)
+                {
+                fprintf(stderr, "avcodecdecode_play: number of channels is zero\n");
+                xlplayer->playmode = PM_EJECTING;
+                return;
+                }
+
+            layout = av_get_default_channel_layout(channels);
+            }
+
+        av_opt_set_int(self->swr, "in_channel_layout", layout, 0);
+        av_opt_set_int(self->swr, "out_channel_layout", (self->channels == 2) ? AV_CH_LAYOUT_STEREO : AV_CH_LAYOUT_MONO, 0);
+        av_opt_set_sample_fmt(self->swr, "in_sample_fmt", self->c->sample_fmt, 0);
+        av_opt_set_sample_fmt(self->swr, "out_sample_fmt", AV_SAMPLE_FMT_FLT, 0);
+
+        if (swr_init(self->swr))
+            {
+            fprintf(stderr, "avcodecdecode_init: swr_init failed\n");
+            xlplayer->playmode = PM_EJECTING;
+            return;
+            }
+        }
+
+    if (self->floatsamples)
+        av_freep(&self->floatsamples);
+
+    if (av_samples_alloc(&self->floatsamples, NULL, 2, frame->nb_samples, AV_SAMPLE_FMT_FLT, 0) < 0)
+        {
+        fprintf(stderr, "avcodecdecode_play: av_samples_alloc failed\n");
+        xlplayer->playmode = PM_EJECTING;
+        return;
+        }
+
+    swr_convert(self->swr, &self->floatsamples, frame->nb_samples, (const uint8_t **)frame->data, frame->nb_samples);
+#else
+
+    if (!(self->floatsamples))
+        {
+        if (channels > 2 || channels < 1)
+            {
+            fprintf(stderr, "avcodecdecode_init: unhandled number of channels: %d\n", channels);
+            xlplayer->playmode = PM_EJECTING;
+            return;
+            }
+
+        if (!(self->floatsamples = malloc(sizeof (float) * self->channels * AVCODEC_MAX_AUDIO_FRAME_SIZE)))
+            {
+            fprintf(stderr, "avcodecdecode_init: malloc failure\n");
+            xlplayer->playmode = PM_EJECTING;
+            return;
+            }
+        }
+
+    int buffer_size = av_samples_get_buffer_size(NULL, channels,
+                        frame->nb_samples, self->c->sample_fmt, 1);
+
+    switch (self->c->sample_fmt) {
+        case AV_SAMPLE_FMT_FLT:
+            frames = (buffer_size >> 2) / channels;
+            memcpy(self->floatsamples, frame->data[0], buffer_size);
+            break;
+
+        case AV_SAMPLE_FMT_FLTP:
+            frames = (buffer_size >> 2) / channels;
+            {
+            float *l = (float *)frame->data[0];
+            float *r = NULL;
+            if (channels == 2)
+                r = (float *)frame->data[1];
+            float *d = self->floatsamples;
+            float *endp = self->floatsamples + (channels * frames);
+            while (d < endp)
+                {
+                *d++ = *l++;
+                if (channels == 2)
+                    *d++ = *r++;
+                }
+            }
+            break;
+
+        case AV_SAMPLE_FMT_DBL:
+            frames  = (buffer_size >> 3) / channels;
+            {
+            double *s = (double *)frame->data[0];
+            float *d = self->floatsamples;
+            float *endp = self->floatsamples + (channels * frames);
+            while (d < endp)
+                *d++ = (float)*s++;
+            }
+            break;
+
+        case AV_SAMPLE_FMT_DBLP:
+            frames  = (buffer_size >> 3) / channels;
+            {
+            double *l = (double *)frame->data[0];
+            double *r = NULL;
+            if (channels == 2)
+                r = (double *)frame->data[1];
+            float *d = self->floatsamples;
+            float *endp = self->floatsamples + (channels * frames);
+            while (d < endp)
+                {
+                *d++ = (float)*l++;
+                if (channels == 2)
+                    *d++ = (float)*r++;
+                }
+            }
+            break;
+
+        case AV_SAMPLE_FMT_S16:
+             frames = (buffer_size >> 1) / channels;
+            xlplayer_make_audio_to_float(xlplayer, self->floatsamples,
+                            frame->data[0], frames, 16, channels);
+            break;
+
+        case AV_SAMPLE_FMT_S16P:
+            frames = (buffer_size >> 1) / channels;
+            {
+            int16_t *l = (int16_t *)frame->data[0];
+            int16_t *r = NULL;
+            if (channels == 2)
+                r = (int16_t *)frame->data[1];
+            float *d = self->floatsamples;
+            float *endp = self->floatsamples + (channels * frames);
+            while (d < endp)
+                {
+                *d++ = *l++ / 32768.0f;
+                if (channels == 2)
+                    *d++ = *r++ / 32768.0f;
+                }
+            }
+            break;
+
+        case AV_SAMPLE_FMT_S32:
+            frames = (buffer_size >> 2) / channels;
+            xlplayer_make_audio_to_float(xlplayer, self->floatsamples,
+                            frame->data[0], frames, 32, channels);
+            break;
+
+        case AV_SAMPLE_FMT_S32P:
+            frames = (buffer_size >> 2) / channels;
+            {
+            int32_t *l = (int32_t *)frame->data[0];
+            int32_t *r = NULL;
+            if (channels == 2)
+                r = (int32_t *)frame->data[1];
+            float *d = self->floatsamples;
+            float *endp = self->floatsamples + (channels * frames);
+            while (d < endp)
+                {
+                *d++ = *l++ / 1073741824.0f;
+                if (channels == 2)
+                    *d++ = *r++ / 1073741824.0f;
+                }
+            }
+            break;
+
+        case AV_SAMPLE_FMT_NONE:
+            fprintf(stderr, "avcodecdecode_play: sample format is none\n");
+            xlplayer->playmode = PM_EJECTING;
+            return;
+
+        default:
+            fprintf(stderr, "avcodecdecode_play: unexpected data format %d\n", (int)self->c->sample_fmt);
+            xlplayer->playmode = PM_EJECTING;
+            return;
+        }
+
+#endif /* defined (HAVE_SWRESAMPLE) && defined(USE_SWRESAMPLE) */
+
+    if (self->resample)
+        {
+        src_data->input_frames = frame->nb_samples;
+        src_data->data_in = (float *)self->floatsamples;
+        if (src_process(xlplayer->src_state, src_data))
+            {
+            fprintf(stderr, "avcodecdecode_play: error occured during resampling\n");
+            xlplayer->playmode = PM_EJECTING;
+            return;
+            }
+        xlplayer_demux_channel_data(xlplayer, src_data->data_out, frames = src_data->output_frames_gen, self->channels, 1.f);
+        }
+    else
+        xlplayer_demux_channel_data(xlplayer, (float *)self->floatsamples, frames = frame->nb_samples, self->channels, 1.f);
+
+    if (self->drop > 0)
+        self->drop -= frames / (float)xlplayer->samplerate;
+    else
+        xlplayer_write_channel_data(xlplayer);
+    }
+
+
 static void avcodecdecode_eject(struct xlplayer *xlplayer)
     {
     struct avcodecdecode_vars *self = xlplayer->dec_data;
 
+    fprintf(stderr, "started eject\n");
     if (self->pkt.data)
-        av_free_packet(&self->pkt);
+        av_packet_unref(&self->pkt);
     if (self->resample)
         {
         xlplayer->src_state = src_delete(xlplayer->src_state);
@@ -72,11 +292,13 @@ static void avcodecdecode_eject(struct xlplayer *xlplayer)
 #endif
     while (pthread_mutex_trylock(&g.avc_mutex))
         nanosleep(&time_delay, NULL);
-    avcodec_close(self->c);
+    avcodec_free_context(&self->c);
     pthread_mutex_unlock(&g.avc_mutex);
     avformat_close_input(&self->ic);
+#ifndef HAVE_AVCODEC_SEND_PACKET
     if (self->frame)
         av_freep(&self->frame);
+#endif
     free(self);
     fprintf(stderr, "finished eject\n");
     }
@@ -85,7 +307,7 @@ static void avcodecdecode_init(struct xlplayer *xlplayer)
     {
     struct avcodecdecode_vars *self = xlplayer->dec_data;
     int src_error;
-    
+
     if (xlplayer->seek_s)
         {
         av_seek_frame(self->ic, -1, (int64_t)xlplayer->seek_s * AV_TIME_BASE, 0);
@@ -99,16 +321,16 @@ static void avcodecdecode_init(struct xlplayer *xlplayer)
                 break;
             }
         }
-        
+
     self->channels = (self->c->channels == 1) ? 1 : 2;
     if ((self->resample = (self->c->sample_rate != (int)xlplayer->samplerate)))
         {
         fprintf(stderr, "configuring resampler\n");
         xlplayer->src_data.src_ratio = (double)xlplayer->samplerate / (double)self->c->sample_rate;
         xlplayer->src_data.end_of_input = 0;
-        
+
         const size_t dsiz = AVCODEC_MAX_AUDIO_FRAME_SIZE * self->channels * xlplayer->src_data.src_ratio + 512;
-        
+
         xlplayer->src_data.output_frames = dsiz / (sizeof (float) * self->channels);
         if (!(xlplayer->src_data.data_out = malloc(dsiz)))
             {
@@ -130,22 +352,109 @@ static void avcodecdecode_init(struct xlplayer *xlplayer)
             return;
             }
         }
-        
+
     fprintf(stderr, "avcodecdecode_init: completed\n");
     }
-    
+
+#ifdef HAVE_AVCODEC_SEND_PACKET
+
+static void avcodecdecode_play(struct xlplayer *xlplayer)
+{
+    struct avcodecdecode_vars *self = xlplayer->dec_data;
+    int channels = self->c->channels;
+    SRC_DATA *src_data = &xlplayer->src_data;
+
+    for(;;) {
+        switch(avcodec_receive_frame(self->c, &self->af)) {
+            case 0:
+                /* successfully got an audio frame */
+                write_frame(xlplayer, &self->af);
+                return;
+            case AVERROR(EAGAIN):
+                for(;;)
+                    {
+                    /* obtain a new packet */
+                    if (av_read_frame(self->ic, &self->pkt) < 0 || self->pkt.size == 0)
+                        goto cleanup;
+                    /* drop this packet if it's not for our audio stream */
+                    if (self->pkt.stream_index != (int)self->stream)
+                        {
+                        if (self->pkt.data)
+                            av_packet_unref(&self->pkt);
+                        }
+                    else
+                        break;
+                    }
+                /* feed in the audio packet */
+                if (avcodec_send_packet(self->c, &self->pkt))
+                    {
+                    fprintf(stderr, "avcodecdecode_play: avcodec_send_packet failed\n");
+                    goto cleanup;
+                    }
+                av_packet_unref(&self->pkt);
+                /* update metadata if needed (checking once per packet) */
+                int delay = xlplayer_calc_rbdelay(xlplayer);
+                struct chapter *chapter = mp3_tag_chapter_scan(&self->taginfo, xlplayer->play_progress_ms + delay);
+                if (chapter && chapter != self->current_chapter)
+                    {
+                    self->current_chapter = chapter;
+                    xlplayer_set_dynamic_metadata(xlplayer, dynamic_metadata_form[chapter->title.encoding], chapter->artist.text, chapter->title.text, chapter->album.text, delay);
+                    }
+                break;
+
+            case AVERROR(EINVAL):
+                fprintf(stderr, "avcodecdecode_play: wtf happened?\n");
+                goto cleanup;
+
+            case AVERROR_EOF:
+                /* terminal packet received */
+                fprintf(stderr, "avcodecdecode_play: EOF\n");
+                goto cleanup;
+
+            default:
+                fprintf(stderr, "avcodecdecode_play: unexpected error\n");
+                goto cleanup;
+            }
+        }
+    return;
+
+cleanup:
+    if (self->af.data)
+        av_frame_unref(&self->af);
+
+    if (self->pkt.data)
+        av_packet_unref(&self->pkt);
+
+    if (self->resample)       /* flush the resampler */
+        {
+        src_data->end_of_input = TRUE;
+        src_data->input_frames = 0;
+        if (src_process(xlplayer->src_state, src_data))
+            {
+            fprintf(stderr, "avcodecdecode_play: error occured during resampling\n");
+            xlplayer->playmode = PM_EJECTING;
+            return;
+            }
+        xlplayer_demux_channel_data(xlplayer, src_data->data_out, src_data->output_frames_gen, channels, 1.f);
+        xlplayer_write_channel_data(xlplayer);
+        }
+    xlplayer->playmode = PM_FLUSH;
+}
+
+#else
+
 static void avcodecdecode_play(struct xlplayer *xlplayer)
     {
     struct avcodecdecode_vars *self = xlplayer->dec_data;
     int channels = self->c->channels;
     SRC_DATA *src_data = &xlplayer->src_data;
-    
+
     if (self->size <= 0)
         {
         if (av_read_frame(self->ic, &self->pkt) < 0 || (self->size = self->pkt.size) == 0)
             {
             if (self->pkt.data)
-                av_free_packet(&self->pkt);
+                av_packet_unref(&self->pkt);
 
             if (self->resample)       /* flush the resampler */
                 {
@@ -169,7 +478,7 @@ static void avcodecdecode_play(struct xlplayer *xlplayer)
     if (self->pkt.stream_index != (int)self->stream)
         {
         if (self->pkt.data)
-            av_free_packet(&self->pkt);
+            av_packet_unref(&self->pkt);
         self->size = 0;
         return;
         }
@@ -177,7 +486,7 @@ static void avcodecdecode_play(struct xlplayer *xlplayer)
     do
         {
         int len, frames, got_frame = 0;
-        
+
         if (!self->frame)
             {
             if (!(self->frame = av_frame_alloc()))
@@ -209,218 +518,14 @@ static void avcodecdecode_play(struct xlplayer *xlplayer)
             continue;
             }
 
-#if defined (HAVE_SWRESAMPLE) && defined(USE_SWRESAMPLE)
-        if (!self->swr)
-            {
-            int64_t layout;
-            
-            if (!(self->swr = swr_alloc()))
-                {
-                fprintf(stderr, "avcodecdecode_play: call to swr_alloc failed\n");
-                xlplayer->playmode = PM_EJECTING;
-                return;
-                }
+        write_frame(xlplayer, self->frame);
 
-            layout = self->frame->channel_layout;
-            if (!layout)
-                layout = self->c->channel_layout;
-            if (!layout)
-                {
-                if (!channels)
-                    {
-                    fprintf(stderr, "avcodecdecode_play: number of channels is zero\n");
-                    xlplayer->playmode = PM_EJECTING;
-                    return;
-                    }
-                
-                layout = av_get_default_channel_layout(channels);
-                }
-
-            av_opt_set_int(self->swr, "in_channel_layout", layout, 0);
-            av_opt_set_int(self->swr, "out_channel_layout", (self->channels == 2) ? AV_CH_LAYOUT_STEREO : AV_CH_LAYOUT_MONO, 0);
-            av_opt_set_sample_fmt(self->swr, "in_sample_fmt", self->c->sample_fmt, 0);
-            av_opt_set_sample_fmt(self->swr, "out_sample_fmt", AV_SAMPLE_FMT_FLT, 0);
-
-            if (swr_init(self->swr))
-                {
-                fprintf(stderr, "avcodecdecode_init: swr_init failed\n");
-                xlplayer->playmode = PM_EJECTING;
-                return;
-                }
-            }
-
-        if (self->floatsamples)
-            av_freep(&self->floatsamples);
-
-        if (av_samples_alloc(&self->floatsamples, NULL, 2, self->frame->nb_samples, AV_SAMPLE_FMT_FLT, 0) < 0)
-            {
-            fprintf(stderr, "avcodecdecode_play: av_samples_alloc failed\n");
-            xlplayer->playmode = PM_EJECTING;
-            return;
-            }
-
-        swr_convert(self->swr, &self->floatsamples, self->frame->nb_samples, (const uint8_t **)self->frame->data, self->frame->nb_samples);
-#else
-        
-        if (!(self->floatsamples))
-            {
-            if (channels > 2 || channels < 1)
-                {
-                fprintf(stderr, "avcodecdecode_init: unhandled number of channels: %d\n", channels);
-                xlplayer->playmode = PM_EJECTING;
-                return;
-                }
-                
-            if (!(self->floatsamples = malloc(sizeof (float) * self->channels * AVCODEC_MAX_AUDIO_FRAME_SIZE)))
-                {
-                fprintf(stderr, "avcodecdecode_init: malloc failure\n");
-                xlplayer->playmode = PM_EJECTING;
-                return;
-                }
-            }
-
-        int buffer_size = av_samples_get_buffer_size(NULL, channels,
-                            self->frame->nb_samples, self->c->sample_fmt, 1);
-
-        switch (self->c->sample_fmt) {
-            case AV_SAMPLE_FMT_FLT:
-                frames = (buffer_size >> 2) / channels;
-                memcpy(self->floatsamples, self->frame->data[0], buffer_size);
-                break;
-                
-            case AV_SAMPLE_FMT_FLTP:
-                frames = (buffer_size >> 2) / channels;
-                {
-                float *l = (float *)self->frame->data[0];
-                float *r = NULL;
-                if (channels == 2)
-                    r = (float *)self->frame->data[1];
-                float *d = self->floatsamples;
-                float *endp = self->floatsamples + (channels * frames);
-                while (d < endp)
-                    {
-                    *d++ = *l++;
-                    if (channels == 2)
-                        *d++ = *r++;
-                    }
-                }
-                break;
-
-            case AV_SAMPLE_FMT_DBL:
-                frames  = (buffer_size >> 3) / channels;
-                {
-                double *s = (double *)self->frame->data[0];
-                float *d = self->floatsamples;
-                float *endp = self->floatsamples + (channels * frames);
-                while (d < endp)
-                    *d++ = (float)*s++;
-                }
-                break;
-
-            case AV_SAMPLE_FMT_DBLP:
-                frames  = (buffer_size >> 3) / channels;
-                {
-                double *l = (double *)self->frame->data[0];
-                double *r = NULL;
-                if (channels == 2)
-                    r = (double *)self->frame->data[1];
-                float *d = self->floatsamples;
-                float *endp = self->floatsamples + (channels * frames);
-                while (d < endp)
-                    {
-                    *d++ = (float)*l++;
-                    if (channels == 2)
-                        *d++ = (float)*r++;
-                    }
-                }
-                break;
-                
-            case AV_SAMPLE_FMT_S16:
-                 frames = (buffer_size >> 1) / channels;
-                xlplayer_make_audio_to_float(xlplayer, self->floatsamples,
-                                self->frame->data[0], frames, 16, channels);
-                break;
-
-            case AV_SAMPLE_FMT_S16P:
-                frames = (buffer_size >> 1) / channels;
-                {
-                int16_t *l = (int16_t *)self->frame->data[0];
-                int16_t *r = NULL;
-                if (channels == 2)
-                    r = (int16_t *)self->frame->data[1];
-                float *d = self->floatsamples;
-                float *endp = self->floatsamples + (channels * frames);
-                while (d < endp)
-                    {
-                    *d++ = *l++ / 32768.0f;
-                    if (channels == 2)
-                        *d++ = *r++ / 32768.0f;
-                    }
-                }
-                break;
-                
-            case AV_SAMPLE_FMT_S32:
-                frames = (buffer_size >> 2) / channels;
-                xlplayer_make_audio_to_float(xlplayer, self->floatsamples,
-                                self->frame->data[0], frames, 32, channels);
-                break;
-
-            case AV_SAMPLE_FMT_S32P:
-                frames = (buffer_size >> 2) / channels;
-                {
-                int32_t *l = (int32_t *)self->frame->data[0];
-                int32_t *r = NULL;
-                if (channels == 2)
-                    r = (int32_t *)self->frame->data[1];
-                float *d = self->floatsamples;
-                float *endp = self->floatsamples + (channels * frames);
-                while (d < endp)
-                    {
-                    *d++ = *l++ / 1073741824.0f;
-                    if (channels == 2)
-                        *d++ = *r++ / 1073741824.0f;
-                    }
-                }
-                break;
-
-            case AV_SAMPLE_FMT_NONE:
-                fprintf(stderr, "avcodecdecode_play: sample format is none\n");
-                xlplayer->playmode = PM_EJECTING;
-                return;
-
-            default:
-                fprintf(stderr, "avcodecdecode_play: unexpected data format %d\n", (int)self->c->sample_fmt);
-                xlplayer->playmode = PM_EJECTING;
-                return;
-            }
-   
-#endif /* defined (HAVE_SWRESAMPLE) && defined(USE_SWRESAMPLE) */
-
-        if (self->resample)
-            {
-            src_data->input_frames = self->frame->nb_samples;
-            src_data->data_in = (float *)self->floatsamples;
-            if (src_process(xlplayer->src_state, src_data))
-                {
-                fprintf(stderr, "avcodecdecode_play: error occured during resampling\n");
-                xlplayer->playmode = PM_EJECTING;
-                return;
-                }
-            xlplayer_demux_channel_data(xlplayer, src_data->data_out, frames = src_data->output_frames_gen, self->channels, 1.f);
-            }
-        else
-            xlplayer_demux_channel_data(xlplayer, (float *)self->floatsamples, frames = self->frame->nb_samples, self->channels, 1.f);
-            
-        if (self->drop > 0)
-            self->drop -= frames / (float)xlplayer->samplerate;
-        else
-            xlplayer_write_channel_data(xlplayer);
         } while (!xlplayer->write_deferred && self->size > 0);
 
     if (self->size <= 0)
         {
         if (self->pkt.data)
-            av_free_packet(&self->pkt);
+            av_packet_unref(&self->pkt);
         int delay = xlplayer_calc_rbdelay(xlplayer);
         struct chapter *chapter = mp3_tag_chapter_scan(&self->taginfo, xlplayer->play_progress_ms + delay);
         if (chapter && chapter != self->current_chapter)
@@ -431,20 +536,22 @@ static void avcodecdecode_play(struct xlplayer *xlplayer)
         }
     }
 
+#endif /* HAVE_AVCODEC_SEND_PACKET */
+
+
 int avcodecdecode_reg(struct xlplayer *xlplayer)
     {
     struct avcodecdecode_vars *self;
     FILE *fp;
     struct chapter *chapter;
-    
+    int ret;
+
     if (!(xlplayer->dec_data = self = calloc(1, sizeof (struct avcodecdecode_vars))))
         {
         fprintf(stderr, "avcodecdecode_reg: malloc failure\n");
         return REJECTED;
         }
-    else
-        xlplayer->dec_data = self;
-    
+
     if ((fp = fopen(xlplayer->pathname, "r")))
         {
         mp3_tag_read(&self->taginfo, fp);
@@ -455,7 +562,7 @@ int avcodecdecode_reg(struct xlplayer *xlplayer)
             }
         fclose(fp);
         }
-    
+
     if (avformat_open_input(&self->ic, xlplayer->pathname, NULL, NULL) < 0)
         {
         fprintf(stderr, "avcodecdecode_reg: failed to open input file %s\n", xlplayer->pathname);
@@ -463,7 +570,12 @@ int avcodecdecode_reg(struct xlplayer *xlplayer)
         return REJECTED;
         }
 
-    if (avformat_find_stream_info(self->ic, NULL) < 0)
+    while (pthread_mutex_trylock(&g.avc_mutex))
+        nanosleep(&time_delay, NULL);
+    ret = avformat_find_stream_info(self->ic, NULL);
+    pthread_mutex_unlock(&g.avc_mutex);
+
+    if (ret < 0)
         {
         fprintf(stderr, "avcodecdecode_reg: call to avformat_find_stream_info failed\n");
         avformat_close_input(&self->ic);
@@ -473,16 +585,34 @@ int avcodecdecode_reg(struct xlplayer *xlplayer)
 
     while (pthread_mutex_trylock(&g.avc_mutex))
         nanosleep(&time_delay, NULL);
-    if ((self->stream = av_find_best_stream(self->ic, AVMEDIA_TYPE_AUDIO, -1, -1, &self->codec, 0)) < 0)
+    self->stream = av_find_best_stream(self->ic, AVMEDIA_TYPE_AUDIO, -1, -1, &self->codec, 0);
+    pthread_mutex_unlock(&g.avc_mutex);
+
+    if (self->stream < 0)
         {
         fprintf(stderr, "Cannot find an audio stream in the input file\n");
         avformat_close_input(&self->ic);
         free(self);
         return REJECTED;
         }
-    pthread_mutex_unlock(&g.avc_mutex);
 
-    self->c = self->ic->streams[self->stream]->codec;
+    /* Allocate a codec context for the decoder */
+    self->c = avcodec_alloc_context3(self->codec);
+    if (!(self->c = avcodec_alloc_context3(self->codec))) {
+        fprintf(stderr, "failed to allocate the codec context\n");
+        avformat_close_input(&self->ic);
+        free(self);
+        return REJECTED;
+    }
+    /* Copy codec parameters from input stream to output codec context */
+    if (avcodec_parameters_to_context(self->c, self->ic->streams[self->stream]->codecpar) < 0) {
+        fprintf(stderr, "Failed to copy codec parameters to decoder context\n");
+        avformat_close_input(&self->ic);
+        free(self);
+        return REJECTED;
+
+    }
+
 #ifndef USE_SWRESAMPLE
     self->c->request_sample_fmt = AV_SAMPLE_FMT_FLT;
     self->c->request_channel_layout = AV_CH_LAYOUT_STEREO_DOWNMIX;
@@ -503,7 +633,7 @@ int avcodecdecode_reg(struct xlplayer *xlplayer)
     xlplayer->dec_init = avcodecdecode_init;
     xlplayer->dec_play = avcodecdecode_play;
     xlplayer->dec_eject = avcodecdecode_eject;
-    
+
     return ACCEPTED;
     }
 
