@@ -35,7 +35,7 @@
 #include "live_oggspeex_encoder.h"
 #include "live_oggopus_encoder.h"
 #include "live_webm_encoder.h"
-#include "avcodec_encoder.h"
+#include "live_aac_encoder.h"
 #include "bsdcompat.h"
 #include "main.h"
 #ifdef DYN_LAME
@@ -607,7 +607,7 @@ int encoder_start(struct threads_info *ti, struct universal_vars *uv, void *othe
                         case ENCODER_CODEC_AAC:
                         case ENCODER_CODEC_AACPLUSV2:
 #if defined(HAVE_AVCODEC) && defined(HAVE_AVFORMAT)
-                            encoder_init = live_avcodec_encoder_init;
+                            encoder_init = live_aac_encoder_init;
 #endif
                             break;
                         case ENCODER_CODEC_UNHANDLED:
