@@ -29,7 +29,7 @@
 #include "sourceclient.h"
 #include "kvpparse.h"
 #include "live_ogg_encoder.h"
-#include "avcodec_encoder.h"
+#include "live_aac_encoder.h"
 #include "sig.h"
 #include "main.h"
 
@@ -198,7 +198,6 @@ static struct kvpdict kvpdict[] = {
 static struct commandmap commandmap[] = {
     { "jack_samplerate_request", audio_feed_jack_samplerate_request, NULL },
     { "encoder_lame_availability", encoder_init_lame, NULL},
-    { "encoder_aac_availability", live_avcodec_encoder_aac_functionality, NULL},
     { "get_report", get_report, NULL },
     { "encoder_start", encoder_start, &ev },
     { "encoder_stop", encoder_stop, NULL },
