@@ -42,16 +42,9 @@ static void *streamer_main(void *args)
     struct streamer *self = args;
     struct timespec ms10 = { 0, 10000000 };
     struct encoder_op_packet *packet;
-    char buffer[10];
     size_t data_size;
     unsigned connect_time = 0;
     
-    char *s_conv(unsigned long value)
-        {
-        snprintf(buffer, 10, "%lu", value);
-        return buffer;
-        }
-        
     sig_mask_thread();
     while (!self->thread_terminate_f)
         {
