@@ -35,7 +35,7 @@ def pid_exists(pid):
         return False
     try:
         os.kill(pid, 0)
-    except OSError, e:
+    except OSError as e:
         return e.errno == os.errno.EPERM
     else:
         return True
