@@ -17,6 +17,7 @@
 #   along with this program in the file entitled COPYING.
 #   If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import print_function
 from __future__ import absolute_import
 
 import re
@@ -24,6 +25,7 @@ import json
 import time
 import sys
 import threading
+import traceback
 import gettext
 from inspect import getargspec
 from functools import wraps, partial
@@ -36,6 +38,8 @@ try:
     from irc import client
     from irc import events
 except ImportError:
+    traceback.print_exc()
+    print("No IRC support")
     HAVE_IRC = False
 else:
     HAVE_IRC = True
@@ -46,6 +50,7 @@ from .gtkstuff import DefaultEntry
 from .gtkstuff import NamedTreeRowReference
 from .gtkstuff import ConfirmationDialog
 from .gtkstuff import threadslock, gdklock
+from .gtkstuff import timeout_add, source_remove
 from .utils import string_multireplace
 from .tooltips import set_tip
 
@@ -81,13 +86,15 @@ MESSAGE_CATEGORIES = (
         # TC: IRC message subcategory, triggered once when the stream starts.
         _("On stream up"),
         # TC: IRC message subcategory, triggered once at the stream's end.
-        _("On stream down"))
+        _("On stream down"),
+        # TC: IRC message subcategory, triggered once at the stream's end.
+        _("Operations"))
 
 ASCII_C0 = "".join(chr(x) for x in range(32))
 
-CODES_AND_DESCRIPTIONS = zip((u"%r", u"%t", u"%l", u"%s", u"%n", u"%d", u"%u"),
+CODES_AND_DESCRIPTIONS = zip((u"%r", u"%t", u"%l", u"%s", u"%n", u"%d", u"%u", u"%U"),
         (_('Artist'), _('Title'), _('Album'), _('Song name'),
-         _('DJ name'), _('Description'), _('Listen URL')))
+         _('DJ name'), _('Description'), _('Listen URL'), _('Source URI')))
 
 
 class IRCEntry(gtk.Entry):  # pylint: disable=R0904
@@ -534,10 +541,11 @@ message_offset_adj = gtk.Adjustment(0, 0, 9999, 1, 10)
 message_interval_adj = gtk.Adjustment(600, 60, 9999, 1, 10)
 
 
-class MessageDialog(gtk.Dialog):
-    """Base class for a message creation dialog."""
+class ChannelsDialog(gtk.Dialog):
+    """Channels entry dialog."""
     
     icon = gtk.STOCK_NEW
+    title = "missing title"
 
     def __init__(self, title=None):
         if title is None:
@@ -546,38 +554,20 @@ class MessageDialog(gtk.Dialog):
         gtk.Dialog.__init__(
                         self, title + " - IDJC" + ProfileManager().title_extra)
 
-        hbox1 = gtk.HBox()
-        hbox1.set_spacing(6)
+        chbox = gtk.HBox()
+        chbox.set_spacing(6)
         # TC: An IRC channel #chan or user name entry box label.
         l = gtk.Label(_("Channels/Users"))
         self.channels = gtk.Entry()
-        hbox1.pack_start(l, False)
-        hbox1.pack_start(self.channels, True)
+        chbox.pack_start(l, False)
+        chbox.pack_start(self.channels, True)
         set_tip(self.channels, _("The comma or space separated list of channels"
         " and/or users to whom the message will be sent.\n\nProtected channels "
         "are included with the form:\n#channel:keyword."))
         
-        hbox2 = gtk.HBox()
-        hbox2.set_spacing(6)
-        # TC: Message text to send to an IRC channel. Widget label.
-        l = gtk.Label(_("Message"))
-        self.message = IRCEntry()
-        hbox2.pack_start(l, False)
-        hbox2.pack_start(self.message)
-        set_tip(self.message, _("The message to send.\n\nOn the pop-up window "
-        "(mouse right click) are some useful options for embedding metadata and"
-        " for text formatting.\n\nThe window below displays how the message "
-        "will appear to users of XChat."))
-        
-        sw = gtk.ScrolledWindow()
-        sw.set_policy(gtk.POLICY_NEVER, gtk.POLICY_ALWAYS)
-        irc_view = IRCView()
-        sw.add(irc_view)
-        vbox = gtk.VBox()
-        vbox.set_spacing(5)
-        vbox.pack_start(hbox1, False)
-        vbox.pack_start(hbox2, False)
-        vbox.pack_start(sw)
+        self.mainbox = gtk.VBox()
+        self.mainbox.set_spacing(5)
+        self.mainbox.pack_start(chbox, False)
         
         self.hbox = gtk.HBox()
         self.hbox.set_border_width(16)
@@ -585,11 +575,8 @@ class MessageDialog(gtk.Dialog):
         self.image = gtk.image_new_from_stock(self.icon, gtk.ICON_SIZE_DIALOG)
         self.image.set_alignment(0.5, 0)
         self.hbox.pack_start(self.image, False, padding=20)
-        self.hbox.pack_start(vbox)
-        
-        self.message.connect("changed", 
-                                    lambda w: irc_view.set_text(w.get_text()))
-        
+        self.hbox.pack_start(self.mainbox)
+       
         self.get_content_area().add(self.hbox)
         self.channels.grab_focus()
         
@@ -597,6 +584,55 @@ class MessageDialog(gtk.Dialog):
         text = self.channels.get_text().replace(",", " ").split()
         return ",".join(x for x in text if x)
 
+    def as_tuple(self):
+        """Data extraction method."""
+
+        return (self._from_channels(),)
+
+
+class EditChannelsDialog(ChannelsDialog, EditDialogMixin):
+    """Adds delete and restore buttons to a channels dialog."""
+    
+    icon = gtk.STOCK_EDIT
+
+    def __init__(self, title, orig_data):
+        ChannelsDialog.__init__(self, title)
+        EditDialogMixin.__init__(self, orig_data)
+        
+    def from_tuple(self, orig_data):
+        """The data restore method."""
+        
+        self.channels.set_text(orig_data[0])
+
+
+class MessageDialog(ChannelsDialog):
+    """Message entry dialog."""
+    
+    def __init__(self, title=None):
+        ChannelsDialog.__init__(self, title)
+        
+        hbox = gtk.HBox()
+        hbox.set_spacing(6)
+        # TC: Message text to send to an IRC channel. Widget label.
+        l = gtk.Label(_("Message"))
+        self.message = IRCEntry()
+        hbox.pack_start(l, False)
+        hbox.pack_start(self.message)
+        set_tip(self.message, _("The message to send.\n\nOn the pop-up window "
+        "(mouse right click) are some useful options for embedding metadata and"
+        " for text formatting.\n\nThe window below displays how the message "
+        "will appear to users of XChat."))
+        self.mainbox.pack_start(hbox, False)
+        
+        sw = gtk.ScrolledWindow()
+        sw.set_policy(gtk.POLICY_NEVER, gtk.POLICY_ALWAYS)
+        irc_view = IRCView()
+        sw.add(irc_view)
+        self.mainbox.pack_start(sw, False)
+        
+        self.message.connect("changed", 
+                                    lambda w: irc_view.set_text(w.get_text()))
+
     def _pack(self, widgets):
         vbox = gtk.VBox()
         for l, w in widgets:
@@ -818,7 +854,9 @@ class IRCRowReference(NamedTreeRowReference):
         
         7: {"channels":5, "message":6},
 
-        9: {"channels":5, "message":6}
+        9: {"channels":5, "message":6},
+        
+        11: {"channels":5}
         }
 
     def get_index_for_name(self, tree_row_ref, name):
@@ -968,7 +1006,7 @@ class IRCPane(gtk.VBox):
                 return
 
             if store.pop(0) != self._m_signature():
-                print "IRC server data format mismatch."
+                print("IRC server data format mismatch.")
                 return
                 
             selection = self._treeview.get_selection()
@@ -1029,25 +1067,31 @@ class IRCPane(gtk.VBox):
                     text += " " + ", ".join(opt)
             else:
                 channels = row.channels
-                message = row.message
+
+                if row.type < 11:
+                    message = row.message
                 
-                if row.type == 3:
-                    text = "+%d;%s; %s" % (row.delay, channels, message)
-                elif row.type == 5:
-                    text = "%d/%d;%s; %s" % (
-                                    row.offset, row.interval, channels, message)
-                else:
-                    text = channels + "; " + message
+                    if row.type == 3:
+                        text = "+%d;%s; %s" % (row.delay, channels, message)
+                    elif row.type == 5:
+                        text = "%d/%d;%s; %s" % (
+                                row.offset, row.interval, channels, message)
+                    elif row.type in (7, 9):
+                        text = channels + "; " + message
+                elif row.type == 11:
+                    text = channels
         else:
             text = (("Server", ) + MESSAGE_CATEGORIES)[row.type / 2]
 
         cell.props.text = text
 
 
-    # TC: Expander text encapsulating messages that play when stream goes up.
+    # TC: Dialog title text.
     _dsu = _("IRC stream up message")
-    # TC: Expander text encapsulating messages that play when stream goes down.
+    # TC: Dialog title text.
     _dsd = _("IRC stream down message")
+    # TC: Dialog title text.
+    _dso = _("IRC station operations")
 
     @glue
     def _on_new(self, mode, model, iter, dialog):
@@ -1060,28 +1104,32 @@ class IRCPane(gtk.VBox):
         elif mode in (6, 8):
             title = self._dsu if mode == 6 else self._dsd
             dialog(MessageDialog(title), self._add_message, mode)
+        elif mode == 10:
+            dialog(ChannelsDialog(self._dso), self._add_channels, mode)
         else:
-            if mode / 2 < len(MESSAGE_CATEGORIES):
-                print "there is no data entry dialog implemented for the '%s'" \
-                            " message category" % MESSAGE_CATEGORIES[mode / 2]
-            else:
-                print "unknown message category with numerical code,", mode
+            self._unhandled_mode(mode)
 
     @glue
     def _on_edit(self, mode, model, iter, dialog):
+        row = tuple(model[model.get_path(iter)])
+        
         if mode == 1:
-            dialog(EditServerDialog(tuple(model[model.get_path(iter)])[2:14]),
-                                                    self._standard_edit, 2)
-        if mode == 3:
-            dialog(EditAnnounceMessageDialog(tuple(model[model.get_path(iter)])
-                                                [4:7]), self._standard_edit, 4)
-        if mode == 5:
-            dialog(EditTimerMessageDialog(tuple(model[model.get_path(iter)])
-                                                [3:7]), self._standard_edit, 3)
-        if mode in (7, 9):
+            dialog(EditServerDialog(row[2:14]), self._standard_edit, 2)
+        elif mode == 3:
+            dialog(EditAnnounceMessageDialog(row[4:7]), self._standard_edit, 4)
+        elif mode == 5:
+            dialog(EditTimerMessageDialog(row[3:7]), self._standard_edit, 3)
+        elif mode in (7, 9):
             title = self._dsu if mode == 7 else self._dsd
-            dialog(EditMessageDialog(title, tuple(
-                model[model.get_path(iter)])[5:7]), self._standard_edit, 5)
+            dialog(EditMessageDialog(title, row[5:7]), self._standard_edit, 5)
+        elif mode == 11:
+            dialog(EditChannelsDialog(self._dso, row[5:6]), self._standard_edit, 5)
+        else:
+            self._unhandled_mode(mode)
+
+    @staticmethod
+    def _unhandled_mode(mode):
+        print("unhandled message category with numerical code,", mode)
 
     def _standard_edit(self, d, model, iter, start):
         model.row_changed_block()
@@ -1120,6 +1168,11 @@ class IRCPane(gtk.VBox):
         return model.insert(parent_iter, 0, (mode + 1, 1, 0, 0, 0) 
                                                 + d.as_tuple() + ("", ) * 8)
 
+    @highlight
+    def _add_channels(self, d, model, parent_iter, mode):
+        return model.insert(parent_iter, 0, (mode + 1, 1, 0, 0, 0) 
+                                                + d.as_tuple() + ("", ) * 9)
+
 
 class ConnectionsController(list):
     """Layer between the user interface and the ServerConnection classes.
@@ -1184,8 +1237,12 @@ class IRCConnection(gtk.TreeRowReference, threading.Thread):
         self._keepalive = True
         self._have_welcome = False
         self._stream_active = stream_active
-        self.irc = client.IRC()
-        self.server = self.irc.server()
+        try:
+            self.reactor = client.Reactor()
+        except AttributeError:
+            self.reactor = client.IRC()  # Old API compatibility
+            
+        self.server = self.reactor.server()
         self.start()
         self._hooks.append((model, model.connect("row-inserted",
                                                         self._on_row_inserted)))
@@ -1287,28 +1344,28 @@ class IRCConnection(gtk.TreeRowReference, threading.Thread):
                         model = ref.get_model()
                         path = ref.get_path()
                         if not ref.valid() or not model.path_is_active(path):
-                            print "IRC connection attempt cancelled"
+                            print("IRC connection attempt cancelled")
                             return
 
-                        print "Attempting to connect IRC %s:%d" % (
-                                                            hostname, port)
+                        print("Attempting to connect IRC %s:%d" % 
+                              (hostname, port))
                         try:
                             connect()
                         except client.ServerConnectionError as e:
-                            print e
+                            print(e)
                             try:
                                 delay = delays[0]
                             except IndexError:
-                                print "No more connection attempts"
+                                print("No more connection attempts")
                                 self._ui_set_nick("")
                             else:
-                                print "%d more tries" % len(delays)
+                                print("%d more tries" % len(delays))
                                 self.server.execute_delayed(delay, try_connect,
                                                                     delays[1:])
                         else:
                             self._ui_set_nick(nickname)
-                            print "New IRC connection: %s@%s:%d" % (
-                                                    nickname, hostname, port)
+                            print("New IRC connection: %s@%s:%d" %
+                                  (nickname, hostname, port))
                                                     
                     try_connect(1, 2, 3)
             else:
@@ -1316,7 +1373,7 @@ class IRCConnection(gtk.TreeRowReference, threading.Thread):
                     try:
                         self.server.disconnect()
                     except client.ServerConnectionError as e:
-                        print >>sys.stderr, str(e)
+                        print(str(e), file=sys.stderr)
                     self._ui_set_nick("")
 
             self._queue.append(deferred)
@@ -1333,9 +1390,9 @@ class IRCConnection(gtk.TreeRowReference, threading.Thread):
             while len(self._queue):
                 self._queue.pop(0)()
             
-            self.irc.process_once(0.2)
+            self.reactor.process_once(0.2)
         
-        self.irc.process_once()
+        self.reactor.process_once()
 
     def cleanup(self):
         for each in self._message_handlers:
@@ -1349,7 +1406,7 @@ class IRCConnection(gtk.TreeRowReference, threading.Thread):
                 try:
                     self.server.disconnect()
                 except client.ServerConnectionError as e:
-                    print >>sys.stderr, str(e)
+                    print(str(e), file=sys.stderr)
                 self._ui_set_nick("")
 
             self._queue.append(deferred)
@@ -1381,7 +1438,7 @@ class IRCConnection(gtk.TreeRowReference, threading.Thread):
 
     @threadslock
     def _on_welcome(self, server, event):
-        print "Got IRC welcome", event.source
+        print("Got IRC welcome", event.source)
         self._have_welcome = True
         self._channels_invalidate()
         model = self.get_model()
@@ -1401,7 +1458,7 @@ class IRCConnection(gtk.TreeRowReference, threading.Thread):
             self._nick_recover(server, target, nspw)
 
     def _nick_recover(self, server, target, nspw):
-        print "Will issue recover and release commands to NickServ"
+        print("Will issue recover and release commands to NickServ")
         for i, (func, args) in enumerate((
                 (server.privmsg, (
                                 "NickServ", "RECOVER %s %s" % (target, nspw))),
@@ -1417,7 +1474,7 @@ class IRCConnection(gtk.TreeRowReference, threading.Thread):
             source = source.split("@")[0]
             
             if source != "Global!services":
-                print "-%s- %s" % (source, event.arguments[0])
+                print("-%s- %s" % (source, event.arguments[0]))
                 
             if source == "NickServ!services":
                 with gdklock():
@@ -1425,7 +1482,7 @@ class IRCConnection(gtk.TreeRowReference, threading.Thread):
 
                 if "NickServ IDENTIFY" in event.arguments[0] and nspw:
                     server.privmsg("NickServ", "IDENTIFY %s" % nspw)
-                    print "Issued IDENTIFY command to NickServ"
+                    print("Issued IDENTIFY command to NickServ")
                     self._ui_set_nick(event.target)
                 elif "Guest" in event.arguments[0]:
                     newnick = event.arguments[0].split()[-1].strip(ASCII_C0)
@@ -1440,7 +1497,7 @@ class IRCConnection(gtk.TreeRowReference, threading.Thread):
     def _on_disconnect(self, server, event):
         self._have_welcome = False
         self._ui_set_nick("")
-        print event.source, "disconnected"
+        print(event.source, "disconnected")
 
     def _on_nicknameinuse(self, server, event):
         self._try_alternate_nick()
@@ -1455,7 +1512,7 @@ class IRCConnection(gtk.TreeRowReference, threading.Thread):
         self._try_alternate_nick()
 
     def _on_join(self, server, event):
-        print "Channel joined", event.target
+        print("Channel joined", event.target)
 
     def _on_ctcp(self, server, event):
         source = event.source.split("!")[0]
@@ -1509,17 +1566,17 @@ class IRCConnection(gtk.TreeRowReference, threading.Thread):
 
         else:
             pass
-            #print "CTCP from", source, args
+            #print("CTCP from", source, args)
 
     def _on_motd(self, server, event):
         pass
 
     def _generic_handler(self, server, event):
         return
-        print "Type:", event.eventtype()
-        print "Source:", event.source()
-        print "Target:", event.target()
-        print "Args:", event.arguments()
+        print("Type:", event.eventtype())
+        print("Source:", event.source())
+        print("Target:", event.target())
+        print("Args:", event.arguments())
 
 
 class MessageHandler(gobject.GObject):
@@ -1542,10 +1599,10 @@ class MessageHandler(gobject.GObject):
     def stream_active(self):
         return self._stream_active
 
-    subst_keys = ("artist", "title", "album", "songname",
-                                                "djname", "description", "url")
+    subst_keys = ("artist", "title", "album", "songname", "djname",
+                                    "description", "url", "source")
 
-    subst_tokens = ("%r", "%t", "%l", "%s", "%n", "%d", "%u")
+    subst_tokens = ("%r", "%t", "%l", "%s", "%n", "%d", "%u", "%U")
 
     subst = dict.fromkeys(subst_keys, "<No data>")
 
@@ -1624,7 +1681,7 @@ class MessageHandler(gobject.GObject):
         else:
             raise AttributeError("unknown property '%s'" % prop.name)
 
-    def issue_messages(self, delay_calc=lambda row: 0):
+    def issue_messages(self, delay_calc=lambda row: 0, forced_message=None):
         model = self.tree_row_ref.get_model()
         iter = model.get_iter(self.tree_row_ref.get_path())
         iter = model.iter_children(iter)
@@ -1637,7 +1694,10 @@ class MessageHandler(gobject.GObject):
                     targets = [x.split("!")[0] for x in row.channels.split(",")]
                     table = [("%%", "%")] + zip(self.subst_tokens, (
                                         self.subst[x] for x in self.subst_keys))
-                    message = string_multireplace(row.message, table)
+                    if forced_message is not None:
+                        message = string_multireplace(forced_message, table)
+                    else:
+                        message = string_multireplace(row.message, table)
                     self.emit("privmsg-ready", targets, message, delay_s)
           
             iter = model.iter_next(iter)
@@ -1657,11 +1717,11 @@ class MessageHandlerForType_5(MessageHandler):
             self.on_stream_active()
 
     def on_stream_active(self):
-        self._timeout_id = gobject.timeout_add(500, self._timeout)
+        self._timeout_id = timeout_add(500, self._timeout)
 
     def on_stream_inactive(self):
         if self._timeout_id is not None:
-            gobject.source_remove(self._timeout_id)
+            source_remove(self._timeout_id)
             self._timeout_id = None
 
     @threadslock
@@ -1680,7 +1740,7 @@ class MessageHandlerForType_5(MessageHandler):
             
     def cleanup(self):
         if self._timeout_id is not None:
-            gobject.source_remove(self._timeout_id)
+            source_remove(self._timeout_id)
 
 
 class MessageHandlerForType_7(MessageHandler):
@@ -1691,3 +1751,10 @@ class MessageHandlerForType_7(MessageHandler):
 class MessageHandlerForType_9(MessageHandler):
     def on_stream_inactive(self):
         self.issue_messages()
+
+class MessageHandlerForType_11(MessageHandler):
+    def on_stream_active(self):
+        self.issue_messages(forced_message="!handover acquired %U")
+    
+    def on_stream_inactive(self):
+        self.issue_messages(forced_message="!handover dropped %U")
