@@ -15,6 +15,7 @@
 #   along with this program in the file entitled COPYING.
 #   If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import print_function
 
 import os
 import time
@@ -87,7 +88,7 @@ class Effect(gtk.HBox):
         self.pack_start(self.led, False)
         self.old_ledval = 0
         
-        image = gtk.image_new_from_file(FGlobs.pkgdatadir / "stop.png")
+        image = gtk.image_new_from_file(PGlobs.themedir / "stop.png")
         image.set_padding(4, 4)
         self.stop = gtk.Button()
         self.stop.set_image(image)
@@ -115,7 +116,7 @@ class Effect(gtk.HBox):
         
         self.repeat = gtk.ToggleButton()
         image = gtk.Image()
-        pb = gtk.gdk.pixbuf_new_from_file_at_size(FGlobs.pkgdatadir / "repeat.png", 23, 19)
+        pb = gtk.gdk.pixbuf_new_from_file_at_size(PGlobs.themedir / "repeat.png", 23, 19)
         image.set_from_pixbuf(pb)
         self.repeat.add(image)
         image.show()
@@ -425,13 +426,13 @@ class EffectBank(gtk.Frame):
         level_vbox = gtk.VBox()
         hbox.pack_start(level_vbox, False, padding=3)
         
-        vol_image = gtk.image_new_from_file(FGlobs.pkgdatadir / "volume2.png")
+        vol_image = gtk.image_new_from_file(PGlobs.themedir / "volume2.png")
         vol = gtk.VScale(vol_adj)
         vol.set_inverted(True)
         vol.set_draw_value(False)
         set_tip(vol, _('Effects volume.'))
 
-        pb = gtk.gdk.pixbuf_new_from_file(FGlobs.pkgdatadir / "headroom.png")
+        pb = gtk.gdk.pixbuf_new_from_file(PGlobs.themedir / "headroom.png")
         mute_image = gtk.image_new_from_pixbuf(pb)
         mute = gtk.VScale(mute_adj)
         mute.set_inverted(True)
@@ -456,14 +457,14 @@ class EffectBank(gtk.Frame):
             with open(PM.basedir / self.session_filename, "r") as f:
                 self.unmarshall(f.read())
         except IOError:
-            print "failed to read effects session file"
+            print("failed to read effects session file")
 
     def save_session(self, where):
         try:
             with open((where or PM.basedir) / self.session_filename, "w") as f:
                 f.write(self.marshall())
         except IOError:
-            print "failed to write effects session file"
+            print("failed to write effects session file")
 
     def update_leds(self, bits):
         for bit, each in enumerate(self.effects):
@@ -608,7 +609,7 @@ class ExtraPlayers(gtk.HBox):
 
         ilevel_vbox = gtk.VBox()
         hbox.pack_start(ilevel_vbox, False, padding=3)
-        volpb = gtk.gdk.pixbuf_new_from_file(FGlobs.pkgdatadir / "volume2.png")
+        volpb = gtk.gdk.pixbuf_new_from_file(PGlobs.themedir / "volume2.png")
         ivol_image = gtk.image_new_from_pixbuf(volpb)
         ilevel_vbox.pack_start(ivol_image, False, padding=2)
         ivol = gtk.VScale(self.ivol_adj)
