@@ -15,6 +15,7 @@
 #   along with this program in the file entitled COPYING.
 #   If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import print_function
 
 __all__ = ['MutagenGUI']
 
@@ -137,7 +138,7 @@ class WMATagger(MutagenTagger):
                             tag[key] = [
                                     ASFUnicodeAttribute(val.decode("utf-8"))]
                         except KeyError:
-                            print "Unacceptable key", key
+                            print("Unacceptable key", key)
         tag.save()
 
     
@@ -179,7 +180,7 @@ class WMATagger(MutagenTagger):
             if not isinstance(self.tag, mutagen.asf.ASF):
                 raise mutagen.asf.error
         except mutagen.asf.error:
-            print "Not a real wma/asf file apparently."
+            print("Not a real wma/asf file apparently.")
             self.tag = None
             return
             
@@ -320,14 +321,14 @@ class ID3Tagger(MutagenTagger):
                 if not isinstance(self.tag, MP3):
                     raise mutagen.mp3.error
             except mutagen.mp3.error:
-                print "Not a real mp3 file apparently."
+                print("Not a real mp3 file apparently.")
                 self.tag = None
                 return
             try:
                 self.tag.add_tags()
-                print "Added ID3 tags to", pathname
+                print("Added ID3 tags to", pathname)
             except mutagen.id3.error:
-                print "Existing ID3 tags found."
+                print("Existing ID3 tags found.")
         else:
             try:
                 # Obtain ID3 tags from a non mp3 file.
@@ -438,7 +439,7 @@ class MP4Tagger(MutagenTagger):
             if not isinstance(self.tag, mutagen.mp4.MP4):
                 raise mutagen.mp4.error
         except mutagen.mp4.error:
-            print "Not a real mp4 file apparently."
+            print("Not a real mp4 file apparently.")
             self.tag = None
             return
             
@@ -494,7 +495,7 @@ class NativeTagger(MutagenTagger):
                         try:
                             tag[key] = [val.decode("utf-8")]
                         except KeyError:
-                            print "Unacceptable key", key
+                            print("Unacceptable key", key)
     
         tag.save() 
 
@@ -571,7 +572,7 @@ class ApeTagger(MutagenTagger):
                         try:
                             tag[key] = APETextValue(val.decode("utf-8"), 0)
                         except KeyError:
-                            print "Unacceptable key", key
+                            print("Unacceptable key", key)
     
         tag.save() 
 
@@ -610,22 +611,22 @@ class ApeTagger(MutagenTagger):
             try:
                 self.tag = APEv2(pathname)
             except:
-                print "ape tag not found"
+                print("ape tag not found")
                 self.tag = None
                 return
             else:
-                print "ape tag found on non-native format"
+                print("ape tag found on non-native format")
         except:
-            print "failed to create tagger for native format"
+            print("failed to create tagger for native format")
             self.tag = None
             return
         else:
             try:
                 self.tag.add_tags()
             except:
-                print "ape tag found on native format"
+                print("ape tag found on native format")
             else:
-                print "no existing ape tags found"
+                print("no existing ape tags found")
             
         self.tag_frame = FreeTagFrame()
         self.add(self.tag_frame)
@@ -664,7 +665,7 @@ class MutagenGUI:
         extension = os.path.splitext(pathname)[1][1:].lower()
         if supported.count(extension) != 1:
             if extension:
-                print "File type", extension, "is not supported for tagging"
+                print("File type", extension, "is not supported for tagging")
             return False
         else:
             return extension
@@ -672,12 +673,12 @@ class MutagenGUI:
     
     def __init__(self, pathname, encoding, idjcroot = None):
         if not pathname:
-            print "Tagger not supplied any pathname."
+            print("Tagger not supplied any pathname.")
             return
         
         extension = self.is_supported(pathname)
         if extension == False:
-            print "Tagger file extension", extension, "not supported."
+            print("Tagger file extension", extension, "not supported.")
             return
         
         self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
@@ -785,5 +786,5 @@ class MutagenGUI:
                                             gtk.Window.destroy, self.window)
             self.window.show()
         except IOError as e:
-            print e
+            print(e)
             self.window.destroy()
