@@ -15,6 +15,7 @@
 #   along with this program in the file entitled COPYING.
 #   If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import print_function
 
 import os
 import shutil
@@ -174,7 +175,7 @@ class PanWidget(gtk.Frame):
         try:
             target = int(self._presets[index].get_value() + 0.5)
         except IndexError:
-            print "Attempt made to load a non existent pan preset"
+            print("Attempt made to load a non existent pan preset")
         else:
             if self._source_id:
                 source_remove(self._source_id)
@@ -725,8 +726,11 @@ class mixprefs:
                 for name, widget in self.rrvaluesdict.iteritems():
                     f.write(name + "=" + str(int(widget.get_value())) + "\n")
                 f.write("num_effects=%d\n" % (24 if self.more_effects.get_active() else 12))
+                f.write("[misc]\n")
+                f.write("theme=%s\n" % ("darktheme" if self.dark_theme.get_active() else "lighttheme"))
+                
         except IOError:
-            print "Error while writing out player defaults"
+            print("Error while writing out player defaults")
 
 
     def save_player_prefs(self, where=None):
@@ -743,7 +747,7 @@ class mixprefs:
                     else:
                         f.write(name + "=\n")
         except IOError:
-            print "Error while writing out player defaults"
+            print("Error while writing out player defaults")
 
             
     def load_player_prefs(self):
@@ -777,7 +781,7 @@ class mixprefs:
                     self.textdict[key].set_text(value)
             file.close()
         except IOError:
-            print "Failed to read playerdefaults file"
+            print("Failed to read playerdefaults file")
         if songdb_active:
             self.activedict["songdb_active"].set_active(songdb_active)
         self.parent.send_new_mixer_stats()
@@ -1119,6 +1123,41 @@ class mixprefs:
         self.rrvaluesdict = {"num_micpairs": self.mic_qty_adj,
                                     "num_streamers": self.stream_qty_adj,
                                     "num_recorders": self.recorder_qty_adj}
+                  
+        def theme_frame_factory(path):
+            frame = gtk.Frame()
+            frame.set_border_width(1)
+            box = gtk.HBox()
+            box.set_border_width(2)
+            box.set_spacing(12)
+            frame.add(box)
+            
+            def image(name):
+                pathname = path / name + ".png"
+                pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(pathname,
+                                                              16, 16)
+                image = gtk.image_new_from_pixbuf(pixbuf)
+                return image
+                
+            for each in "play2 pause stop next repeat".split():
+                box.pack_start(image(each), False)
+            
+            frame.show_all()
+            return frame      
+                                    
+        self.light_theme = gtk.RadioButton(None)
+        self.light_theme.add(theme_frame_factory(FGlobs.lightthemedir))
+        self.dark_theme = gtk.RadioButton(self.light_theme)
+        self.dark_theme.add(theme_frame_factory(FGlobs.darkthemedir))
+        if PGlobs.theme == "darktheme":
+            self.dark_theme.set_active(True)
+        hbox = gtk.HBox()
+        hbox.pack_start(self.light_theme, False)
+        self.light_theme.show()
+        hbox.pack_start(self.dark_theme, False)
+        self.dark_theme.show()
+        rrvbox.pack_start(hbox)
+        hbox.show()
         
         # Meters on/off
         
